Notebook Helpers
================

.. py:module:: sandal.notebook

The :py:mod:`sandal.notebook` module contains helpers for working in notebook
environments.

Logging
-------

It's useful to set up logging to dump to :py:attr:`sys.stderr` in notebook environments.

.. autofunction:: setup_logging
